@@ -18,10 +18,7 @@ class EnergyManagementSystemSensor(DataObject):
         the report (.rdd) or meter dictionary file (.mdd) if the Output:VariableDictionary
         has been requested.
     """
-    schema = {'min-fields': 3,
-              'name': u'EnergyManagementSystem:Sensor',
-              'pyname': u'EnergyManagementSystemSensor',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -43,10 +40,13 @@ class EnergyManagementSystemSensor(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'external-list'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Energy Management System',
+              'min-fields': 3,
+              'name': u'EnergyManagementSystem:Sensor',
+              'pyname': u'EnergyManagementSystemSensor',
               'required-object': False,
-              'group': u'Energy Management System'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -130,10 +130,7 @@ class EnergyManagementSystemActuator(DataObject):
     """ Corresponds to IDD object `EnergyManagementSystem:Actuator`
         Hardware portion of EMS used to set up actuators in the model
     """
-    schema = {'min-fields': 4,
-              'name': u'EnergyManagementSystem:Actuator',
-              'pyname': u'EnergyManagementSystemActuator',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -162,10 +159,13 @@ class EnergyManagementSystemActuator(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Energy Management System',
+              'min-fields': 4,
+              'name': u'EnergyManagementSystem:Actuator',
+              'pyname': u'EnergyManagementSystemActuator',
               'required-object': False,
-              'group': u'Energy Management System'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -278,10 +278,13 @@ class EnergyManagementSystemProgramCallingManager(DataObject):
         a description of when it should be called
         and then lines of program code for EMS Runtime language
     """
-    schema = {'min-fields': 3,
-              'name': u'EnergyManagementSystem:ProgramCallingManager',
-              'pyname': u'EnergyManagementSystemProgramCallingManager',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'program name 1',
+                                                 {'name': u'Program Name 1',
+                                                  'pyname': u'program_name_1',
+                                                  'required-field': True,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'object-list'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -311,16 +314,13 @@ class EnergyManagementSystemProgramCallingManager(DataObject):
                                                            u'UnitarySystemSizing'],
                                        'autocalculatable': False,
                                        'type': 'alpha'})]),
-              'extensible-fields': OrderedDict([(u'program name 1',
-                                                 {'name': u'Program Name 1',
-                                                  'pyname': u'program_name_1',
-                                                  'required-field': True,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'object-list'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Energy Management System',
+              'min-fields': 3,
+              'name': u'EnergyManagementSystem:ProgramCallingManager',
+              'pyname': u'EnergyManagementSystemProgramCallingManager',
               'required-object': False,
-              'group': u'Energy Management System'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -415,10 +415,13 @@ class EnergyManagementSystemProgram(DataObject):
         This input defines an Erl program
         Each field after the name is a line of EMS Runtime Language
     """
-    schema = {'min-fields': 2,
-              'name': u'EnergyManagementSystem:Program',
-              'pyname': u'EnergyManagementSystemProgram',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'program line 1',
+                                                 {'name': u'Program Line 1',
+                                                  'pyname': u'program_line_1',
+                                                  'required-field': False,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'alpha'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -426,16 +429,13 @@ class EnergyManagementSystemProgram(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'alpha'})]),
-              'extensible-fields': OrderedDict([(u'program line 1',
-                                                 {'name': u'Program Line 1',
-                                                  'pyname': u'program_line_1',
-                                                  'required-field': False,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'alpha'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Energy Management System',
+              'min-fields': 2,
+              'name': u'EnergyManagementSystem:Program',
+              'pyname': u'EnergyManagementSystemProgram',
               'required-object': False,
-              'group': u'Energy Management System'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -505,10 +505,13 @@ class EnergyManagementSystemSubroutine(DataObject):
         This input defines an Erl program subroutine
         Each field after the name is a line of EMS Runtime Language
     """
-    schema = {'min-fields': 2,
-              'name': u'EnergyManagementSystem:Subroutine',
-              'pyname': u'EnergyManagementSystemSubroutine',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'program line',
+                                                 {'name': u'Program Line',
+                                                  'pyname': u'program_line',
+                                                  'required-field': False,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'alpha'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -516,16 +519,13 @@ class EnergyManagementSystemSubroutine(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'alpha'})]),
-              'extensible-fields': OrderedDict([(u'program line',
-                                                 {'name': u'Program Line',
-                                                  'pyname': u'program_line',
-                                                  'required-field': False,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'alpha'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Energy Management System',
+              'min-fields': 2,
+              'name': u'EnergyManagementSystem:Subroutine',
+              'pyname': u'EnergyManagementSystemSubroutine',
               'required-object': False,
-              'group': u'Energy Management System'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -595,21 +595,21 @@ class EnergyManagementSystemGlobalVariable(DataObject):
         Declares Erl variable as having global scope
         No spaces allowed in names used for Erl variables
     """
-    schema = {'min-fields': 1,
-              'name': u'EnergyManagementSystem:GlobalVariable',
-              'pyname': u'EnergyManagementSystemGlobalVariable',
-              'format': None,
-              'fields': OrderedDict(),
-              'extensible-fields': OrderedDict([(u'erl variable 1 name',
+    schema = {'extensible-fields': OrderedDict([(u'erl variable 1 name',
                                                  {'name': u'Erl Variable 1 Name',
                                                   'pyname': u'erl_variable_1_name',
                                                   'required-field': False,
                                                   'autosizable': False,
                                                   'autocalculatable': False,
                                                   'type': u'alpha'})]),
-              'unique-object': False,
+              'fields': OrderedDict(),
+              'format': None,
+              'group': u'Energy Management System',
+              'min-fields': 1,
+              'name': u'EnergyManagementSystem:GlobalVariable',
+              'pyname': u'EnergyManagementSystemGlobalVariable',
               'required-object': False,
-              'group': u'Energy Management System'}
+              'unique-object': False}
 
     def add_extensible(self,
                        erl_variable_1_name=None,
@@ -655,10 +655,7 @@ class EnergyManagementSystemOutputVariable(DataObject):
     """ Corresponds to IDD object `EnergyManagementSystem:OutputVariable`
         This object sets up an EnergyPlus output variable from an Erl variable
     """
-    schema = {'min-fields': 4,
-              'name': u'EnergyManagementSystem:OutputVariable',
-              'pyname': u'EnergyManagementSystemOutputVariable',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -705,10 +702,13 @@ class EnergyManagementSystemOutputVariable(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Energy Management System',
+              'min-fields': 4,
+              'name': u'EnergyManagementSystem:OutputVariable',
+              'pyname': u'EnergyManagementSystemOutputVariable',
               'required-object': False,
-              'group': u'Energy Management System'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -871,10 +871,7 @@ class EnergyManagementSystemMeteredOutputVariable(DataObject):
     """ Corresponds to IDD object `EnergyManagementSystem:MeteredOutputVariable`
         This object sets up an EnergyPlus output variable from an Erl variable
     """
-    schema = {'min-fields': 7,
-              'name': u'EnergyManagementSystem:MeteredOutputVariable',
-              'pyname': u'EnergyManagementSystemMeteredOutputVariable',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -980,10 +977,13 @@ class EnergyManagementSystemMeteredOutputVariable(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Energy Management System',
+              'min-fields': 7,
+              'name': u'EnergyManagementSystem:MeteredOutputVariable',
+              'pyname': u'EnergyManagementSystemMeteredOutputVariable',
               'required-object': False,
-              'group': u'Energy Management System'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1225,10 +1225,7 @@ class EnergyManagementSystemTrendVariable(DataObject):
         This object sets up an EMS trend variable from an Erl variable
         A trend variable logs values across timesteps
     """
-    schema = {'min-fields': 3,
-              'name': u'EnergyManagementSystem:TrendVariable',
-              'pyname': u'EnergyManagementSystemTrendVariable',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1251,10 +1248,13 @@ class EnergyManagementSystemTrendVariable(DataObject):
                                        'minimum': 1,
                                        'autocalculatable': False,
                                        'type': u'integer'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Energy Management System',
+              'min-fields': 3,
+              'name': u'EnergyManagementSystem:TrendVariable',
+              'pyname': u'EnergyManagementSystemTrendVariable',
               'required-object': False,
-              'group': u'Energy Management System'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1341,10 +1341,7 @@ class EnergyManagementSystemInternalVariable(DataObject):
     """ Corresponds to IDD object `EnergyManagementSystem:InternalVariable`
         Declares EMS variable as an internal data variable
     """
-    schema = {'min-fields': 3,
-              'name': u'EnergyManagementSystem:InternalVariable',
-              'pyname': u'EnergyManagementSystemInternalVariable',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1366,10 +1363,13 @@ class EnergyManagementSystemInternalVariable(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Energy Management System',
+              'min-fields': 3,
+              'name': u'EnergyManagementSystem:InternalVariable',
+              'pyname': u'EnergyManagementSystemInternalVariable',
               'required-object': False,
-              'group': u'Energy Management System'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1455,10 +1455,7 @@ class EnergyManagementSystemCurveOrTableIndexVariable(DataObject):
     """ Corresponds to IDD object `EnergyManagementSystem:CurveOrTableIndexVariable`
         Declares EMS variable that identifies a curve or table
     """
-    schema = {'min-fields': 2,
-              'name': u'EnergyManagementSystem:CurveOrTableIndexVariable',
-              'pyname': u'EnergyManagementSystemCurveOrTableIndexVariable',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1473,10 +1470,13 @@ class EnergyManagementSystemCurveOrTableIndexVariable(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'object-list'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Energy Management System',
+              'min-fields': 2,
+              'name': u'EnergyManagementSystem:CurveOrTableIndexVariable',
+              'pyname': u'EnergyManagementSystemCurveOrTableIndexVariable',
               'required-object': False,
-              'group': u'Energy Management System'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1537,10 +1537,7 @@ class EnergyManagementSystemConstructionIndexVariable(DataObject):
     """ Corresponds to IDD object `EnergyManagementSystem:ConstructionIndexVariable`
         Declares EMS variable that identifies a construction
     """
-    schema = {'min-fields': 2,
-              'name': u'EnergyManagementSystem:ConstructionIndexVariable',
-              'pyname': u'EnergyManagementSystemConstructionIndexVariable',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1555,10 +1552,13 @@ class EnergyManagementSystemConstructionIndexVariable(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'object-list'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Energy Management System',
+              'min-fields': 2,
+              'name': u'EnergyManagementSystem:ConstructionIndexVariable',
+              'pyname': u'EnergyManagementSystemConstructionIndexVariable',
               'required-object': False,
-              'group': u'Energy Management System'}
+              'unique-object': False}
 
     @property
     def name(self):
