@@ -16,10 +16,7 @@ class EvaporativeCoolerDirectCelDekPad(DataObject):
         Direct evaporative cooler with rigid media evaporative pad and recirculating water
         pump. This model has no controls other than its availability schedule.
     """
-    schema = {'min-fields': 0,
-              'name': u'EvaporativeCooler:Direct:CelDekPad',
-              'pyname': u'EvaporativeCoolerDirectCelDekPad',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -88,10 +85,13 @@ class EvaporativeCoolerDirectCelDekPad(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'object-list'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Evaporative Coolers',
+              'min-fields': 0,
+              'name': u'EvaporativeCooler:Direct:CelDekPad',
+              'pyname': u'EvaporativeCoolerDirectCelDekPad',
               'required-object': False,
-              'group': u'Evaporative Coolers'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -336,10 +336,7 @@ class EvaporativeCoolerIndirectCelDekPad(DataObject):
         pump, and secondary air fan. This model has no controls other than its availability
         schedule.
     """
-    schema = {'min-fields': 0,
-              'name': u'EvaporativeCooler:Indirect:CelDekPad',
-              'pyname': u'EvaporativeCoolerIndirectCelDekPad',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -450,10 +447,13 @@ class EvaporativeCoolerIndirectCelDekPad(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'node'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Evaporative Coolers',
+              'min-fields': 0,
+              'name': u'EvaporativeCooler:Indirect:CelDekPad',
+              'pyname': u'EvaporativeCoolerIndirectCelDekPad',
               'required-object': False,
-              'group': u'Evaporative Coolers'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -827,10 +827,7 @@ class EvaporativeCoolerIndirectWetCoil(DataObject):
         Indirect evaporative cooler with wetted coil, recirculating water pump, and secondary
         air fan. This model has no controls other than its availability schedule.
     """
-    schema = {'min-fields': 0,
-              'name': u'EvaporativeCooler:Indirect:WetCoil',
-              'pyname': u'EvaporativeCoolerIndirectWetCoil',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -931,10 +928,13 @@ class EvaporativeCoolerIndirectWetCoil(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'node'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Evaporative Coolers',
+              'min-fields': 0,
+              'name': u'EvaporativeCooler:Indirect:WetCoil',
+              'pyname': u'EvaporativeCoolerIndirectWetCoil',
               'required-object': False,
-              'group': u'Evaporative Coolers'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1283,10 +1283,7 @@ class EvaporativeCoolerIndirectResearchSpecial(DataObject):
         or wetted coil), recirculating water pump, and secondary air fan. This model is
         controlled to meet the primary air outlet temperature setpoint.
     """
-    schema = {'min-fields': 0,
-              'name': u'EvaporativeCooler:Indirect:ResearchSpecial',
-              'pyname': u'EvaporativeCoolerIndirectResearchSpecial',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1424,10 +1421,13 @@ class EvaporativeCoolerIndirectResearchSpecial(DataObject):
                                        'minimum': 2.0,
                                        'autocalculatable': False,
                                        'type': u'real'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Evaporative Coolers',
+              'min-fields': 0,
+              'name': u'EvaporativeCooler:Indirect:ResearchSpecial',
+              'pyname': u'EvaporativeCoolerIndirectResearchSpecial',
               'required-object': False,
-              'group': u'Evaporative Coolers'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1905,10 +1905,7 @@ class EvaporativeCoolerDirectResearchSpecial(DataObject):
         or similar media), and recirculating water pump, and secondary air fan. This model is
         controlled to meet the primary air outlet temperature setpoint.
     """
-    schema = {'min-fields': 0,
-              'name': u'EvaporativeCooler:Direct:ResearchSpecial',
-              'pyname': u'EvaporativeCoolerDirectResearchSpecial',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1985,10 +1982,13 @@ class EvaporativeCoolerDirectResearchSpecial(DataObject):
                                        'minimum': 2.0,
                                        'autocalculatable': False,
                                        'type': u'real'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Evaporative Coolers',
+              'min-fields': 0,
+              'name': u'EvaporativeCooler:Direct:ResearchSpecial',
+              'pyname': u'EvaporativeCoolerDirectResearchSpecial',
               'required-object': False,
-              'group': u'Evaporative Coolers'}
+              'unique-object': False}
 
     @property
     def name(self):
