@@ -15,10 +15,7 @@ class ExteriorLights(DataObject):
     """ Corresponds to IDD object `Exterior:Lights`
         only used for Meter type reporting, does not affect building loads
     """
-    schema = {'min-fields': 0,
-              'name': u'Exterior:Lights',
-              'pyname': u'ExteriorLights',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -59,10 +56,13 @@ class ExteriorLights(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Exterior Equipment',
+              'min-fields': 0,
+              'name': u'Exterior:Lights',
+              'pyname': u'ExteriorLights',
               'required-object': False,
-              'group': u'Exterior Equipment'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -202,10 +202,7 @@ class ExteriorFuelEquipment(DataObject):
     """ Corresponds to IDD object `Exterior:FuelEquipment`
         only used for Meter type reporting, does not affect building loads
     """
-    schema = {'min-fields': 0,
-              'name': u'Exterior:FuelEquipment',
-              'pyname': u'ExteriorFuelEquipment',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -257,10 +254,13 @@ class ExteriorFuelEquipment(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Exterior Equipment',
+              'min-fields': 0,
+              'name': u'Exterior:FuelEquipment',
+              'pyname': u'ExteriorFuelEquipment',
               'required-object': False,
-              'group': u'Exterior Equipment'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -399,10 +399,7 @@ class ExteriorWaterEquipment(DataObject):
     """ Corresponds to IDD object `Exterior:WaterEquipment`
         only used for Meter type reporting, does not affect building loads
     """
-    schema = {'min-fields': 0,
-              'name': u'Exterior:WaterEquipment',
-              'pyname': u'ExteriorWaterEquipment',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -443,10 +440,13 @@ class ExteriorWaterEquipment(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Exterior Equipment',
+              'min-fields': 0,
+              'name': u'Exterior:WaterEquipment',
+              'pyname': u'ExteriorWaterEquipment',
               'required-object': False,
-              'group': u'Exterior Equipment'}
+              'unique-object': False}
 
     @property
     def name(self):
