@@ -15,10 +15,7 @@ class HumidifierSteamElectric(DataObject):
     """ Corresponds to IDD object `Humidifier:Steam:Electric`
         Electrically heated steam humidifier with fan.
     """
-    schema = {'min-fields': 0,
-              'name': u'Humidifier:Steam:Electric',
-              'pyname': u'HumidifierSteamElectric',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -90,10 +87,13 @@ class HumidifierSteamElectric(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'object-list'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Humidifiers and Dehumidifiers',
+              'min-fields': 0,
+              'name': u'Humidifier:Steam:Electric',
+              'pyname': u'HumidifierSteamElectric',
               'required-object': False,
-              'group': u'Humidifiers and Dehumidifiers'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -349,10 +349,7 @@ class DehumidifierDesiccantNoFans(DataObject):
         desiccant dehumidifier is typically used in an AirLoopHVAC:OutdoorAirSystem,
         but can also be specified in any AirLoopHVAC.
     """
-    schema = {'min-fields': 0,
-              'name': u'Dehumidifier:Desiccant:NoFans',
-              'pyname': u'DehumidifierDesiccantNoFans',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -549,10 +546,13 @@ class DehumidifierDesiccantNoFans(DataObject):
                                        'autocalculatable': False,
                                        'type': u'real',
                                        'unit': u'C'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Humidifiers and Dehumidifiers',
+              'min-fields': 0,
+              'name': u'Dehumidifier:Desiccant:NoFans',
+              'pyname': u'DehumidifierDesiccantNoFans',
               'required-object': False,
-              'group': u'Humidifiers and Dehumidifiers'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1311,10 +1311,7 @@ class DehumidifierDesiccantSystem(DataObject):
         regeneration air streams. The desiccant dehumidifier is typically used
         in an AirLoopHVAC:OutdoorAirSystem, but can also be specified in any AirLoopHVAC.
     """
-    schema = {'min-fields': 8,
-              'name': u'Dehumidifier:Desiccant:System',
-              'pyname': u'DehumidifierDesiccantSystem',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1462,10 +1459,13 @@ class DehumidifierDesiccantSystem(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Humidifiers and Dehumidifiers',
+              'min-fields': 8,
+              'name': u'Dehumidifier:Desiccant:System',
+              'pyname': u'DehumidifierDesiccantSystem',
               'required-object': False,
-              'group': u'Humidifiers and Dehumidifiers'}
+              'unique-object': False}
 
     @property
     def name(self):
