@@ -15,10 +15,7 @@ class FaultModelTemperatureSensorOffsetOutdoorAir(DataObject):
     """ Corresponds to IDD object `FaultModel:TemperatureSensorOffset:OutdoorAir`
         This object describes outdoor air temperature sensor offset
     """
-    schema = {'min-fields': 0,
-              'name': u'FaultModel:TemperatureSensorOffset:OutdoorAir',
-              'pyname': u'FaultModelTemperatureSensorOffsetOutdoorAir',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -66,10 +63,13 @@ class FaultModelTemperatureSensorOffsetOutdoorAir(DataObject):
                                        'type': u'real',
                                        'maximum<': 10.0,
                                        'unit': u'deltaC'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Operational Faults',
+              'min-fields': 0,
+              'name': u'FaultModel:TemperatureSensorOffset:OutdoorAir',
+              'pyname': u'FaultModelTemperatureSensorOffsetOutdoorAir',
               'required-object': False,
-              'group': u'Operational Faults'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -232,10 +232,7 @@ class FaultModelHumiditySensorOffsetOutdoorAir(DataObject):
     """ Corresponds to IDD object `FaultModel:HumiditySensorOffset:OutdoorAir`
         This object describes outdoor air humidity sensor offset
     """
-    schema = {'min-fields': 0,
-              'name': u'FaultModel:HumiditySensorOffset:OutdoorAir',
-              'pyname': u'FaultModelHumiditySensorOffsetOutdoorAir',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -283,10 +280,13 @@ class FaultModelHumiditySensorOffsetOutdoorAir(DataObject):
                                        'type': u'real',
                                        'maximum<': 0.02,
                                        'unit': u'kgWater/kgDryAir'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Operational Faults',
+              'min-fields': 0,
+              'name': u'FaultModel:HumiditySensorOffset:OutdoorAir',
+              'pyname': u'FaultModelHumiditySensorOffsetOutdoorAir',
               'required-object': False,
-              'group': u'Operational Faults'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -449,10 +449,7 @@ class FaultModelEnthalpySensorOffsetOutdoorAir(DataObject):
     """ Corresponds to IDD object `FaultModel:EnthalpySensorOffset:OutdoorAir`
         This object describes outdoor air enthalpy sensor offset
     """
-    schema = {'min-fields': 0,
-              'name': u'FaultModel:EnthalpySensorOffset:OutdoorAir',
-              'pyname': u'FaultModelEnthalpySensorOffsetOutdoorAir',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -500,10 +497,13 @@ class FaultModelEnthalpySensorOffsetOutdoorAir(DataObject):
                                        'type': u'real',
                                        'maximum<': 20000.0,
                                        'unit': u'J/kg'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Operational Faults',
+              'min-fields': 0,
+              'name': u'FaultModel:EnthalpySensorOffset:OutdoorAir',
+              'pyname': u'FaultModelEnthalpySensorOffsetOutdoorAir',
               'required-object': False,
-              'group': u'Operational Faults'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -666,10 +666,7 @@ class FaultModelPressureSensorOffsetOutdoorAir(DataObject):
     """ Corresponds to IDD object `FaultModel:PressureSensorOffset:OutdoorAir`
         This object describes outdoor air pressure sensor offset
     """
-    schema = {'min-fields': 0,
-              'name': u'FaultModel:PressureSensorOffset:OutdoorAir',
-              'pyname': u'FaultModelPressureSensorOffsetOutdoorAir',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -717,10 +714,13 @@ class FaultModelPressureSensorOffsetOutdoorAir(DataObject):
                                        'type': u'real',
                                        'maximum<': 10000.0,
                                        'unit': u'Pa'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Operational Faults',
+              'min-fields': 0,
+              'name': u'FaultModel:PressureSensorOffset:OutdoorAir',
+              'pyname': u'FaultModelPressureSensorOffsetOutdoorAir',
               'required-object': False,
-              'group': u'Operational Faults'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -883,10 +883,7 @@ class FaultModelTemperatureSensorOffsetReturnAir(DataObject):
     """ Corresponds to IDD object `FaultModel:TemperatureSensorOffset:ReturnAir`
         This object describes return air temperature sensor offset
     """
-    schema = {'min-fields': 0,
-              'name': u'FaultModel:TemperatureSensorOffset:ReturnAir',
-              'pyname': u'FaultModelTemperatureSensorOffsetReturnAir',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -934,10 +931,13 @@ class FaultModelTemperatureSensorOffsetReturnAir(DataObject):
                                        'type': u'real',
                                        'maximum<': 10.0,
                                        'unit': u'deltaC'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Operational Faults',
+              'min-fields': 0,
+              'name': u'FaultModel:TemperatureSensorOffset:ReturnAir',
+              'pyname': u'FaultModelTemperatureSensorOffsetReturnAir',
               'required-object': False,
-              'group': u'Operational Faults'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1100,10 +1100,7 @@ class FaultModelEnthalpySensorOffsetReturnAir(DataObject):
     """ Corresponds to IDD object `FaultModel:EnthalpySensorOffset:ReturnAir`
         This object describes return air enthalpy sensor offset
     """
-    schema = {'min-fields': 0,
-              'name': u'FaultModel:EnthalpySensorOffset:ReturnAir',
-              'pyname': u'FaultModelEnthalpySensorOffsetReturnAir',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1151,10 +1148,13 @@ class FaultModelEnthalpySensorOffsetReturnAir(DataObject):
                                        'type': u'real',
                                        'maximum<': 20000.0,
                                        'unit': u'J/kg'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Operational Faults',
+              'min-fields': 0,
+              'name': u'FaultModel:EnthalpySensorOffset:ReturnAir',
+              'pyname': u'FaultModelEnthalpySensorOffsetReturnAir',
               'required-object': False,
-              'group': u'Operational Faults'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1317,10 +1317,7 @@ class FaultModelFoulingCoil(DataObject):
     """ Corresponds to IDD object `FaultModel:Fouling:Coil`
         This object describes fouling water heating or cooling coils
     """
-    schema = {'min-fields': 0,
-              'name': u'FaultModel:Fouling:Coil',
-              'pyname': u'FaultModelFoulingCoil',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1407,10 +1404,13 @@ class FaultModelFoulingCoil(DataObject):
                                        'autocalculatable': False,
                                        'type': u'real',
                                        'unit': u'dimensionless'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Operational Faults',
+              'min-fields': 0,
+              'name': u'FaultModel:Fouling:Coil',
+              'pyname': u'FaultModelFoulingCoil',
               'required-object': False,
-              'group': u'Operational Faults'}
+              'unique-object': False}
 
     @property
     def name(self):
