@@ -14,10 +14,7 @@ class Version(DataObject):
 
     """Corresponds to IDD object `Version` Specifies the EnergyPlus version of
     the IDF file."""
-    schema = {'min-fields': 0,
-              'name': u'Version',
-              'pyname': u'Version',
-              'format': u'singleline',
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'version identifier',
                                       {'name': u'Version Identifier',
                                        'pyname': u'version_identifier',
@@ -26,10 +23,13 @@ class Version(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': 'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': True,
+              'format': u'singleline',
+              'group': u'Simulation Parameters',
+              'min-fields': 0,
+              'name': u'Version',
+              'pyname': u'Version',
               'required-object': False,
-              'group': u'Simulation Parameters'}
+              'unique-object': True}
 
     @property
     def version_identifier(self):
@@ -70,10 +70,7 @@ class SimulationControl(DataObject):
         Note also, if you want to do system sizing, you must also do zone sizing in the same
         run or an error will result.
     """
-    schema = {'min-fields': 0,
-              'name': u'SimulationControl',
-              'pyname': u'SimulationControl',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'do zone sizing calculation',
                                       {'name': u'Do Zone Sizing Calculation',
                                        'pyname': u'do_zone_sizing_calculation',
@@ -124,10 +121,13 @@ class SimulationControl(DataObject):
                                                            u'No'],
                                        'autocalculatable': False,
                                        'type': 'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': True,
+              'format': None,
+              'group': u'Simulation Parameters',
+              'min-fields': 0,
+              'name': u'SimulationControl',
+              'pyname': u'SimulationControl',
               'required-object': False,
-              'group': u'Simulation Parameters'}
+              'unique-object': True}
 
     @property
     def do_zone_sizing_calculation(self):
@@ -276,10 +276,7 @@ class Building(DataObject):
     Site:HeightVariation objects, specifically the Terrain field.
 
     """
-    schema = {'min-fields': 8,
-              'name': u'Building',
-              'pyname': u'Building',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -362,10 +359,13 @@ class Building(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'integer'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': True,
+              'format': None,
+              'group': u'Simulation Parameters',
+              'min-fields': 8,
+              'name': u'Building',
+              'pyname': u'Building',
               'required-object': True,
-              'group': u'Simulation Parameters'}
+              'unique-object': True}
 
     @property
     def name(self):
@@ -593,10 +593,7 @@ class ShadowCalculation(DataObject):
 
     """Corresponds to IDD object `ShadowCalculation` This object is used to
     control details of the solar, shading, and daylighting models."""
-    schema = {'min-fields': 0,
-              'name': u'ShadowCalculation',
-              'pyname': u'ShadowCalculation',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'calculation method',
                                       {'name': u'Calculation Method',
                                        'pyname': u'calculation_method',
@@ -643,10 +640,13 @@ class ShadowCalculation(DataObject):
                                                            u'DetailedSkyDiffuseModeling'],
                                        'autocalculatable': False,
                                        'type': 'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': True,
+              'format': None,
+              'group': u'Simulation Parameters',
+              'min-fields': 0,
+              'name': u'ShadowCalculation',
+              'pyname': u'ShadowCalculation',
               'required-object': False,
-              'group': u'Simulation Parameters'}
+              'unique-object': True}
 
     @property
     def calculation_method(self):
@@ -800,10 +800,7 @@ class SurfaceConvectionAlgorithmInside(DataObject):
     """ Corresponds to IDD object `SurfaceConvectionAlgorithm:Inside`
         Default indoor surface heat transfer convection algorithm to be used for all zones
     """
-    schema = {'min-fields': 0,
-              'name': u'SurfaceConvectionAlgorithm:Inside',
-              'pyname': u'SurfaceConvectionAlgorithmInside',
-              'format': u'singleline',
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'algorithm',
                                       {'name': u'Algorithm',
                                        'pyname': u'algorithm',
@@ -816,10 +813,13 @@ class SurfaceConvectionAlgorithmInside(DataObject):
                                                            u'AdaptiveConvectionAlgorithm'],
                                        'autocalculatable': False,
                                        'type': 'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': True,
+              'format': u'singleline',
+              'group': u'Simulation Parameters',
+              'min-fields': 0,
+              'name': u'SurfaceConvectionAlgorithm:Inside',
+              'pyname': u'SurfaceConvectionAlgorithmInside',
               'required-object': False,
-              'group': u'Simulation Parameters'}
+              'unique-object': True}
 
     @property
     def algorithm(self):
@@ -859,10 +859,7 @@ class SurfaceConvectionAlgorithmOutside(DataObject):
     """ Corresponds to IDD object `SurfaceConvectionAlgorithm:Outside`
         Default outside surface heat transfer convection algorithm to be used for all zones
     """
-    schema = {'min-fields': 0,
-              'name': u'SurfaceConvectionAlgorithm:Outside',
-              'pyname': u'SurfaceConvectionAlgorithmOutside',
-              'format': u'singleline',
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'algorithm',
                                       {'name': u'Algorithm',
                                        'pyname': u'algorithm',
@@ -876,10 +873,13 @@ class SurfaceConvectionAlgorithmOutside(DataObject):
                                                            u'AdaptiveConvectionAlgorithm'],
                                        'autocalculatable': False,
                                        'type': 'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': True,
+              'format': u'singleline',
+              'group': u'Simulation Parameters',
+              'min-fields': 0,
+              'name': u'SurfaceConvectionAlgorithm:Outside',
+              'pyname': u'SurfaceConvectionAlgorithmOutside',
               'required-object': False,
-              'group': u'Simulation Parameters'}
+              'unique-object': True}
 
     @property
     def algorithm(self):
@@ -926,10 +926,7 @@ class HeatBalanceAlgorithm(DataObject):
     Advanced/Research Usage: HAMT (Combined Heat And Moisture Finite Element)
 
     """
-    schema = {'min-fields': 0,
-              'name': u'HeatBalanceAlgorithm',
-              'pyname': u'HeatBalanceAlgorithm',
-              'format': u'singleline',
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'algorithm',
                                       {'name': u'Algorithm',
                                        'pyname': u'algorithm',
@@ -972,10 +969,13 @@ class HeatBalanceAlgorithm(DataObject):
                                        'autocalculatable': False,
                                        'type': 'real',
                                        'unit': u'W/m2-K'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': True,
+              'format': u'singleline',
+              'group': u'Simulation Parameters',
+              'min-fields': 0,
+              'name': u'HeatBalanceAlgorithm',
+              'pyname': u'HeatBalanceAlgorithm',
               'required-object': False,
-              'group': u'Simulation Parameters'}
+              'unique-object': True}
 
     @property
     def algorithm(self):
@@ -1105,10 +1105,7 @@ class HeatBalanceSettingsConductionFiniteDifference(DataObject):
         Determines settings for the Conduction Finite Difference
         algorithm for surface heat transfer modeling.
     """
-    schema = {'min-fields': 0,
-              'name': u'HeatBalanceSettings:ConductionFiniteDifference',
-              'pyname': u'HeatBalanceSettingsConductionFiniteDifference',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'difference scheme',
                                       {'name': u'Difference Scheme',
                                        'pyname': u'difference_scheme',
@@ -1147,10 +1144,13 @@ class HeatBalanceSettingsConductionFiniteDifference(DataObject):
                                        'minimum': 1e-07,
                                        'autocalculatable': False,
                                        'type': u'real'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': True,
+              'format': None,
+              'group': u'Simulation Parameters',
+              'min-fields': 0,
+              'name': u'HeatBalanceSettings:ConductionFiniteDifference',
+              'pyname': u'HeatBalanceSettingsConductionFiniteDifference',
               'required-object': False,
-              'group': u'Simulation Parameters'}
+              'unique-object': True}
 
     @property
     def difference_scheme(self):
@@ -1271,10 +1271,7 @@ class ZoneAirHeatBalanceAlgorithm(DataObject):
 
     """Corresponds to IDD object `ZoneAirHeatBalanceAlgorithm` Determines which
     algorithm will be used to solve the zone air heat balance."""
-    schema = {'min-fields': 0,
-              'name': u'ZoneAirHeatBalanceAlgorithm',
-              'pyname': u'ZoneAirHeatBalanceAlgorithm',
-              'format': u'singleline',
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'algorithm',
                                       {'name': u'Algorithm',
                                        'pyname': u'algorithm',
@@ -1286,10 +1283,13 @@ class ZoneAirHeatBalanceAlgorithm(DataObject):
                                                            u'EulerMethod'],
                                        'autocalculatable': False,
                                        'type': 'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': True,
+              'format': u'singleline',
+              'group': u'Simulation Parameters',
+              'min-fields': 0,
+              'name': u'ZoneAirHeatBalanceAlgorithm',
+              'pyname': u'ZoneAirHeatBalanceAlgorithm',
               'required-object': False,
-              'group': u'Simulation Parameters'}
+              'unique-object': True}
 
     @property
     def algorithm(self):
@@ -1324,10 +1324,7 @@ class ZoneAirContaminantBalance(DataObject):
 
     """Corresponds to IDD object `ZoneAirContaminantBalance` Determines which
     contaminant concentration will be simulates."""
-    schema = {'min-fields': 0,
-              'name': u'ZoneAirContaminantBalance',
-              'pyname': u'ZoneAirContaminantBalance',
-              'format': u'singleline',
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'carbon dioxide concentration',
                                       {'name': u'Carbon Dioxide Concentration',
                                        'pyname': u'carbon_dioxide_concentration',
@@ -1362,10 +1359,13 @@ class ZoneAirContaminantBalance(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'object-list'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': True,
+              'format': u'singleline',
+              'group': u'Simulation Parameters',
+              'min-fields': 0,
+              'name': u'ZoneAirContaminantBalance',
+              'pyname': u'ZoneAirContaminantBalance',
               'required-object': False,
-              'group': u'Simulation Parameters'}
+              'unique-object': True}
 
     @property
     def carbon_dioxide_concentration(self):
@@ -1487,10 +1487,7 @@ class ZoneAirMassFlowConservation(DataObject):
     source zones only.
 
     """
-    schema = {'min-fields': 0,
-              'name': u'ZoneAirMassFlowConservation',
-              'pyname': u'ZoneAirMassFlowConservation',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'adjust zone mixing for zone air mass flow balance',
                                       {'name': u'Adjust Zone Mixing For Zone Air Mass Flow Balance',
                                        'pyname': u'adjust_zone_mixing_for_zone_air_mass_flow_balance',
@@ -1511,10 +1508,13 @@ class ZoneAirMassFlowConservation(DataObject):
                                                            u'AdjustInfiltrationFlow'],
                                        'autocalculatable': False,
                                        'type': 'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': True,
+              'format': None,
+              'group': u'Simulation Parameters',
+              'min-fields': 0,
+              'name': u'ZoneAirMassFlowConservation',
+              'pyname': u'ZoneAirMassFlowConservation',
               'required-object': False,
-              'group': u'Simulation Parameters'}
+              'unique-object': True}
 
     @property
     def adjust_zone_mixing_for_zone_air_mass_flow_balance(self):
@@ -1601,10 +1601,7 @@ class ZoneCapacitanceMultiplierResearchSpecial(DataObject):
     """ Corresponds to IDD object `ZoneCapacitanceMultiplier:ResearchSpecial`
         Multiplier altering the relative capacitance of the air compared to an empty zone
     """
-    schema = {'min-fields': 4,
-              'name': u'ZoneCapacitanceMultiplier:ResearchSpecial',
-              'pyname': u'ZoneCapacitanceMultiplierResearchSpecial',
-              'format': u'singleline',
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'temperature capacity multiplier',
                                       {'name': u'Temperature Capacity Multiplier',
                                        'pyname': u'temperature_capacity_multiplier',
@@ -1641,10 +1638,13 @@ class ZoneCapacitanceMultiplierResearchSpecial(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'real'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': True,
+              'format': u'singleline',
+              'group': u'Simulation Parameters',
+              'min-fields': 4,
+              'name': u'ZoneCapacitanceMultiplier:ResearchSpecial',
+              'pyname': u'ZoneCapacitanceMultiplierResearchSpecial',
               'required-object': False,
-              'group': u'Simulation Parameters'}
+              'unique-object': True}
 
     @property
     def temperature_capacity_multiplier(self):
@@ -1770,10 +1770,7 @@ class Timestep(DataObject):
     timestep for heat transfer and load calculations.
 
     """
-    schema = {'min-fields': 0,
-              'name': u'Timestep',
-              'pyname': u'Timestep',
-              'format': u'singleline',
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'number of timesteps per hour',
                                       {'name': u'Number of Timesteps per Hour',
                                        'pyname': u'number_of_timesteps_per_hour',
@@ -1784,10 +1781,13 @@ class Timestep(DataObject):
                                        'minimum': 1,
                                        'autocalculatable': False,
                                        'type': u'integer'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': True,
+              'format': u'singleline',
+              'group': u'Simulation Parameters',
+              'min-fields': 0,
+              'name': u'Timestep',
+              'pyname': u'Timestep',
               'required-object': False,
-              'group': u'Simulation Parameters'}
+              'unique-object': True}
 
     @property
     def number_of_timesteps_per_hour(self):
@@ -1835,10 +1835,7 @@ class ConvergenceLimits(DataObject):
     caution.
 
     """
-    schema = {'min-fields': 0,
-              'name': u'ConvergenceLimits',
-              'pyname': u'ConvergenceLimits',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'minimum system timestep',
                                       {'name': u'Minimum System Timestep',
                                        'pyname': u'minimum_system_timestep',
@@ -1876,10 +1873,13 @@ class ConvergenceLimits(DataObject):
                                        'minimum': 2,
                                        'autocalculatable': False,
                                        'type': u'integer'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': True,
+              'format': None,
+              'group': u'Simulation Parameters',
+              'min-fields': 0,
+              'name': u'ConvergenceLimits',
+              'pyname': u'ConvergenceLimits',
               'required-object': False,
-              'group': u'Simulation Parameters'}
+              'unique-object': True}
 
     @property
     def minimum_system_timestep(self):
@@ -2003,10 +2003,7 @@ class ProgramControl(DataObject):
 
     """Corresponds to IDD object `ProgramControl` used to support various
     efforts in time reduction for simulation including threading."""
-    schema = {'min-fields': 0,
-              'name': u'ProgramControl',
-              'pyname': u'ProgramControl',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'number of threads allowed',
                                       {'name': u'Number of Threads Allowed',
                                        'pyname': u'number_of_threads_allowed',
@@ -2015,10 +2012,13 @@ class ProgramControl(DataObject):
                                        'minimum': 0,
                                        'autocalculatable': False,
                                        'type': u'integer'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Simulation Parameters',
+              'min-fields': 0,
+              'name': u'ProgramControl',
+              'pyname': u'ProgramControl',
               'required-object': False,
-              'group': u'Simulation Parameters'}
+              'unique-object': False}
 
     @property
     def number_of_threads_allowed(self):
