@@ -20,10 +20,7 @@ class WaterUseEquipment(DataObject):
         water uses to be linked to WaterUse:Storage objects to store and draw reclaimed water.
         The object can also simulate drainwater heat recovery.
     """
-    schema = {'min-fields': 0,
-              'name': u'WaterUse:Equipment',
-              'pyname': u'WaterUseEquipment',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -97,10 +94,13 @@ class WaterUseEquipment(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'object-list'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Water Systems',
+              'min-fields': 0,
+              'name': u'WaterUse:Equipment',
+              'pyname': u'WaterUseEquipment',
               'required-object': False,
-              'group': u'Water Systems'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -367,10 +367,13 @@ class WaterUseConnections(DataObject):
         2. Connections to WaterUse:Storage objects to store and draw reclaimed water
         3. Internal connections to simulate drainwater heat recovery.
     """
-    schema = {'min-fields': 0,
-              'name': u'WaterUse:Connections',
-              'pyname': u'WaterUseConnections',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'water use equipment 1 name',
+                                                 {'name': u'Water Use Equipment 1 Name',
+                                                  'pyname': u'water_use_equipment_1_name',
+                                                  'required-field': True,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'object-list'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -452,16 +455,13 @@ class WaterUseConnections(DataObject):
                                        'autocalculatable': False,
                                        'type': u'real',
                                        'unit': u'W/K'})]),
-              'extensible-fields': OrderedDict([(u'water use equipment 1 name',
-                                                 {'name': u'Water Use Equipment 1 Name',
-                                                  'pyname': u'water_use_equipment_1_name',
-                                                  'required-field': True,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'object-list'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Water Systems',
+              'min-fields': 0,
+              'name': u'WaterUse:Connections',
+              'pyname': u'WaterUseConnections',
               'required-object': False,
-              'group': u'Water Systems'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -765,10 +765,7 @@ class WaterUseStorage(DataObject):
         connections to numerous sources of supply or numerous components with demand. If a
         maximum capacity is not specified, the tank is assumed to have unlimited capacity.
     """
-    schema = {'min-fields': 0,
-              'name': u'WaterUse:Storage',
-              'pyname': u'WaterUseStorage',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -927,10 +924,13 @@ class WaterUseStorage(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'object-list'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Water Systems',
+              'min-fields': 0,
+              'name': u'WaterUse:Storage',
+              'pyname': u'WaterUseStorage',
               'required-object': False,
-              'group': u'Water Systems'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1460,10 +1460,7 @@ class WaterUseWell(DataObject):
         associated WaterUse:Storage which is assumed to be operated as a vented cistern with
         no pressure tank.
     """
-    schema = {'min-fields': 0,
-              'name': u'WaterUse:Well',
-              'pyname': u'WaterUseWell',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1557,10 +1554,13 @@ class WaterUseWell(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'object-list'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Water Systems',
+              'min-fields': 0,
+              'name': u'WaterUse:Well',
+              'pyname': u'WaterUseWell',
               'required-object': False,
-              'group': u'Water Systems'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1879,10 +1879,13 @@ class WaterUseRainCollector(DataObject):
         WaterUse:Storage object. In order to use this object it is necessary to also include
         a Site:Precipitation object to describe the rates of rainfall.
     """
-    schema = {'min-fields': 0,
-              'name': u'WaterUse:RainCollector',
-              'pyname': u'WaterUseRainCollector',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'collection surface 1 name',
+                                                 {'name': u'Collection Surface 1 Name',
+                                                  'pyname': u'collection_surface_1_name',
+                                                  'required-field': True,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'object-list'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1928,16 +1931,13 @@ class WaterUseRainCollector(DataObject):
                                        'autocalculatable': False,
                                        'type': u'real',
                                        'unit': u'm3/s'})]),
-              'extensible-fields': OrderedDict([(u'collection surface 1 name',
-                                                 {'name': u'Collection Surface 1 Name',
-                                                  'pyname': u'collection_surface_1_name',
-                                                  'required-field': True,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'object-list'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Water Systems',
+              'min-fields': 0,
+              'name': u'WaterUse:RainCollector',
+              'pyname': u'WaterUseRainCollector',
               'required-object': False,
-              'group': u'Water Systems'}
+              'unique-object': False}
 
     @property
     def name(self):
