@@ -26,18 +26,7 @@ class ZoneHvacEquipmentList(DataObject):
         be assigned sequence 2 or higher so that it will see the net load after the DOAS air is added
         to the zone.
     """
-    schema = {'min-fields': 0,
-              'name': u'ZoneHVAC:EquipmentList',
-              'pyname': u'ZoneHvacEquipmentList',
-              'format': None,
-              'fields': OrderedDict([(u'name',
-                                      {'name': u'Name',
-                                       'pyname': u'name',
-                                       'required-field': True,
-                                       'autosizable': False,
-                                       'autocalculatable': False,
-                                       'type': 'alpha'})]),
-              'extensible-fields': OrderedDict([(u'zone equipment 1 object type',
+    schema = {'extensible-fields': OrderedDict([(u'zone equipment 1 object type',
                                                  {'name': u'Zone Equipment 1 Object Type',
                                                   'pyname': u'zone_equipment_1_object_type',
                                                   'required-field': True,
@@ -69,8 +58,8 @@ class ZoneHvacEquipmentList(DataObject):
                                                                       u'ZoneHVAC:RefrigerationChillerSet',
                                                                       u'Fan:ZoneExhaust',
                                                                       u'WaterHeater:HeatPump'],
-                                                  'autocalculatable': False,
-                                                  'type': 'alpha'}),
+                                                     'autocalculatable': False,
+                                                     'type': 'alpha'}),
                                                 (u'zone equipment 1 name',
                                                  {'name': u'Zone Equipment 1 Name',
                                                   'pyname': u'zone_equipment_1_name',
@@ -94,9 +83,20 @@ class ZoneHvacEquipmentList(DataObject):
                                                   'minimum': 1,
                                                   'autocalculatable': False,
                                                   'type': u'integer'})]),
-              'unique-object': False,
+              'fields': OrderedDict([(u'name',
+                                      {'name': u'Name',
+                                       'pyname': u'name',
+                                       'required-field': True,
+                                       'autosizable': False,
+                                       'autocalculatable': False,
+                                       'type': 'alpha'})]),
+              'format': None,
+              'group': u'Zone HVAC Equipment Connections',
+              'min-fields': 0,
+              'name': u'ZoneHVAC:EquipmentList',
+              'pyname': u'ZoneHvacEquipmentList',
               'required-object': False,
-              'group': u'Zone HVAC Equipment Connections'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -198,10 +198,7 @@ class ZoneHvacEquipmentConnections(DataObject):
         zone air node, air inlet nodes, air exhaust nodes, and the air return node. A zone
         equipment list is referenced which lists all HVAC equipment connected to the zone.
     """
-    schema = {'min-fields': 0,
-              'name': u'ZoneHVAC:EquipmentConnections',
-              'pyname': u'ZoneHvacEquipmentConnections',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'zone name',
                                       {'name': u'Zone Name',
                                        'pyname': u'zone_name',
@@ -244,10 +241,13 @@ class ZoneHvacEquipmentConnections(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'node'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Zone HVAC Equipment Connections',
+              'min-fields': 0,
+              'name': u'ZoneHVAC:EquipmentConnections',
+              'pyname': u'ZoneHvacEquipmentConnections',
               'required-object': False,
-              'group': u'Zone HVAC Equipment Connections'}
+              'unique-object': False}
 
     @property
     def zone_name(self):
